@@ -53,9 +53,6 @@ mkdir -p YACReader.app/Contents/MacOS/utils
 mkdir -p YACReaderLibrary.app/Contents/MacOS/utils
 mkdir -p YACReaderLibraryServer.app/Contents/MacOS/utils
 
-cp dependencies/qrencode/macx/libqrencode.4.0.0.dylib \
-YACReaderLibrary.app/Contents/MacOS/utils/libqrencode.dylib
-
 cp -R dependencies/7zip/macx/* YACReader.app/Contents/MacOS/utils/
 cp -R dependencies/7zip/macx/* YACReaderLibrary.app/Contents/MacOS/utils/
 cp -R dependencies/7zip/macx/* YACReaderLibraryServer.app/Contents/MacOS/utils/
